@@ -7,6 +7,8 @@ if not SILE.scratch._tableofcontents then
   SILE.scratch._tableofcontents = {}
 end
 
+local toc_used = false
+
 function package:moveTocNodes ()
   local node = SILE.scratch.info.thispage.toc
   if node then
@@ -24,8 +26,8 @@ function package.writeToc (_)
   tocfile:write("return " .. tocdata)
   tocfile:close()
 
-  if not pl.tablex.deepcompare(SILE.scratch.tableofcontents, SILE.scratch._tableofcontents) then
-    io.stderr:write("\n! Warning: table of contents has changed, please rerun SILE to update it.")
+  if toc_used and not pl.tablex.deepcompare(SILE.scratch.tableofcontents, SILE.scratch._tableofcontents) then
+    SU.msg("Notice: the table of contents has changed, please rerun SILE to update it.")
   end
 end
 
@@ -115,6 +117,7 @@ function package:registerCommands ()
   self:registerCommand("tableofcontents", function (options, _)
     local depth = SU.cast("integer", options.depth or 3)
     local linking = SU.boolean(options.linking, true)
+    toc_used = true
     local toc = self:readToc()
     if toc == false then
       SILE.call("tableofcontents:notocmessage")
